package trismegistoplanilla.mysqldao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import org.json.JSONArray;
import org.json.JSONObject;
import trismegistoplanilla.beans.EstadoEstudioBean;
import trismegistoplanilla.dao.EstadoEstudioDAO;
import trismegistoplanilla.utilities.ResponseHelper;
import trismegistoplanilla.utilities.Variables;

public class EstadoEstudioMysqlDAO implements EstadoEstudioDAO {

	@Override
	public JSONObject validarExistenciaEstadoEstudio(EstadoEstudioBean estadoEstudio) {
		System.out.println("EstadoEstudioMysqlDAO: validarExistenciaEstadoEstudio");
		JSONObject jsonValidarExistenciaEstadoEstudio = null;
		ResponseHelper response = new ResponseHelper();
		int existeEstadoEstudio = 0;

		Connection connection = null;
		PreparedStatement ps = null;
		ResultSet rs = null;
		try {
			connection = MysqlDAOFactory.obtenerConexion(Variables.MYSQL_NUEVO_BD_NAME);
			String sql
				= "select "
				+ "count (1) existeEstadoEstudio "
				+ "from nivel_estado "
				+ "inner join dbo.nivel_estudio ON dbo.nivel_estudio.codigo_nivel_estudio = dbo.nivel_estado.codigo_nivel_estudio "
				+ "inner join dbo.estado_estudio ON dbo.estado_estudio.codigo_estado_estudio = dbo.nivel_estado.codigo_estado_estudio "
				+ "where nivel_estudio.estado_registro = 1 "
				+ "and nivel_estado.codigo_nivel_estudio = ? "
				+ "and nivel_estado.codigo_estado_estudio = ?";
			ps = connection.prepareStatement(sql);
			ps.setInt(1, estadoEstudio.getCodigoNivelEstudio());
			ps.setInt(2, estadoEstudio.getCodigoEstadoEstudio());
			rs = ps.executeQuery();
			rs.next();
			existeEstadoEstudio = rs.getInt("existeEstadoEstudio");
			if (existeEstadoEstudio > 0) {
				response.setStatus(true);
				response.setMessage("El estado estudio seleccionado existe.");
			} else {
				response.setStatus(false);
				response.setMessage("El estado estudio seleccionado no existe.");
			}
		} catch (SQLException e) {
			e.printStackTrace();
			response.setStatus(false);
			response.setMessage("Error: " + e.getMessage() + " \n Error Code: [" + e.getErrorCode() + "]");
		} finally {
			try {
				if (rs != null) {
					rs.close();
				}
				if (ps != null) {
					ps.close();
				}
				if (connection != null) {
					connection.close();
				}
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}
		jsonValidarExistenciaEstadoEstudio = new JSONObject(response);
		return jsonValidarExistenciaEstadoEstudio;
	}

	@Override
	public JSONObject listarEstadoEstudio(EstadoEstudioBean estadoEstudio) {
		System.out.println("EstadoEstudioMysqlDAO: listarEstadoEstudio");
		JSONObject jsonListarEstadoEstudio = null;
		JSONArray jsonArrayListarEstadoEstudio = new JSONArray();
		ResponseHelper response = new ResponseHelper();

		Connection connection = null;
		PreparedStatement ps = null;
		ResultSet rs = null;

		try {
			connection = MysqlDAOFactory.obtenerConexion(Variables.MYSQL_NUEVO_BD_NAME);
			String sql
				= "select "
				+ "estado_estudio.codigo_estado_estudio codigoEstadoEstudio, "
				+ "estado_estudio.nombre nombreEstadoEstudio "
				+ "from nivel_estado "
				+ "inner join dbo.estado_estudio ON dbo.estado_estudio.codigo_estado_estudio = dbo.nivel_estado.codigo_estado_estudio "
				+ "where estado_estudio.estado_registro = 1 and nivel_estado.codigo_nivel_estudio = ?";
			ps = connection.prepareStatement(sql);
			ps.setInt(1, estadoEstudio.getCodigoNivelEstudio());
			rs = ps.executeQuery();
			while (rs.next()) {
				estadoEstudio.setCodigoEstadoEstudio(rs.getInt("codigoEstadoEstudio"));
				estadoEstudio.setNombre(rs.getString("nombreEstadoEstudio"));
				JSONObject jsonObjEstadoEstudio = new JSONObject(estadoEstudio);
				jsonArrayListarEstadoEstudio.put(jsonObjEstadoEstudio);
			}

			JSONObject jsonObjEstadoEstudio = new JSONObject();
			jsonObjEstadoEstudio.put("estadoestudio", jsonArrayListarEstadoEstudio);

			response.setStatus(true);
			response.setMessage("Los estados de estudio se han listado correctamente");
			response.setData(jsonObjEstadoEstudio);

		} catch (SQLException e) {
			e.printStackTrace();
			response.setStatus(false);
			response.setMessage("Error: " + e.getMessage() + " \n Error Code: [" + e.getErrorCode() + "]");
		} finally {
			try {
				if (rs != null) {
					rs.close();
				}
				if (ps != null) {
					ps.close();
				}
				if (connection != null) {
					connection.close();
				}
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}

		jsonListarEstadoEstudio = new JSONObject(response);
		return jsonListarEstadoEstudio;
	}
}
