package trismegistoplanilla.servlets;

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.json.JSONObject;
import trismegistoplanilla.servicesMysql.VacanteService;
import static trismegistoplanilla.utilities.CustomHttpServletRequest.getBodyJsonObject;

public class VacanteServlet extends HttpServlet {

  private static final long serialVersionUID = 1L;

  @Override
  protected void service(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
    String param = request.getParameter("accion");
    switch (param) {
      case "listarVacanteDT":
        listarVacanteDT(request, response);
        break;
      case "registrarVacante":
        registrarVacante(request, response);
        break;
      case "validarVacante":
        validarVacante(request, response);
        break;
      case "validarVacanteFicha":
        validarVacanteFicha(request, response);
        break;
      case "listarVacanteSimpleTable":
        listarVacanteSimpleTable(request, response);
        break;
      case "generarVacante":
        generarVacante(request, response);
        break;
      default:
        response.setContentType("application/json");
        PrintWriter out = response.getWriter();
        out.print(new JSONObject()
                .put("status", false)
                .put("message", "La accion solicitada no existe"));
    }
  }

  private void listarVacanteDT(HttpServletRequest request, HttpServletResponse response) throws IOException {
    response.setContentType("application/json");
    PrintWriter out = response.getWriter();
    VacanteService service = new VacanteService();
    JSONObject datos = new JSONObject()
            .put("start", request.getParameter("start"))
            .put("length", request.getParameter("length"))
            .put("draw", request.getParameter("draw"))
            .put("json", request.getParameter("json") == null ? "" : new JSONObject(request.getParameter("json")));
    JSONObject respuesta = service.listarVacanteDT(datos);
    out.print(respuesta);
  }

  private void registrarVacante(HttpServletRequest request, HttpServletResponse response) throws IOException {
    response.setContentType("application/json");
    VacanteService service = new VacanteService();
    PrintWriter out = response.getWriter();
    JSONObject datos = getBodyJsonObject(request).getJSONObject("json");
    JSONObject respuesta = service.registrarVacante(datos);
    out.print(respuesta);
  }

  private void validarVacante(HttpServletRequest request, HttpServletResponse response) throws IOException {
    response.setContentType("application/json");
    VacanteService service = new VacanteService();
    PrintWriter out = response.getWriter();
    JSONObject datos = getBodyJsonObject(request).getJSONObject("json");
    JSONObject respuesta = service.validarVacante(datos);
    out.print(respuesta);
  }

  private void validarVacanteFicha(HttpServletRequest request, HttpServletResponse response) throws IOException {
    response.setContentType("application/json");
    VacanteService service = new VacanteService();
    PrintWriter out = response.getWriter();
    /*
    RECIBE UN OBJETO JSON EN EL PAYLOAD
    1- TIPO "INT" - codigoSedeArea
    2- TIPO "INT" - codigoAreaCargo
     */

    JSONObject datos = getBodyJsonObject(request).getJSONObject("json");
    JSONObject respuesta = service.validarVacanteFicha(datos);
    out.print(respuesta);
  }

  private void listarVacanteSimpleTable(HttpServletRequest request, HttpServletResponse response) throws IOException {
    response.setContentType("application/json");
    VacanteService service = new VacanteService();
    PrintWriter out = response.getWriter();
//    JSONObject datos = getBodyJsonObject(request).getJSONObject("json");
    JSONObject respuesta = service.listarVacanteSimpleTable(new JSONObject());
    out.print(respuesta);
  }

  private void generarVacante(HttpServletRequest request, HttpServletResponse response) throws IOException {
    response.setContentType("application/json");
    VacanteService service = new VacanteService();
    PrintWriter out = response.getWriter();
    JSONObject datos = getBodyJsonObject(request).getJSONObject("json");
    JSONObject respuesta = service.generarVacante(datos);
    out.print(respuesta);
  }

}
